@@ -1,6 +1,12 @@
 from django.apps import AppConfig
 
-from . import __description__, __verbose_name__, __version__
+from . import (
+    __description__,
+    __license__,
+    __url__,
+    __verbose_name__,
+    __version__,
+)
 
 
 class CSVExportAppConfig(AppConfig):
@@ -8,6 +14,8 @@ class CSVExportAppConfig(AppConfig):
     verbose_name = __verbose_name__
     description = __description__
     version = __version__
+    license = __license__
+    url = __url__
     angular_site_module = True
     angular_projector_module = False  # TODO
     js_files = [
